@@ -42,6 +42,7 @@ sub _buildErrorCode {
     'Invalid input detected\s+.+\^',
     '% Ambiguous command found at',
     '% Incomplete command found at',
+    '% Wrong parameter found at',
     '(^\s*\^|error:)',
   ];
   return $codes;
@@ -76,7 +77,7 @@ sub runCommands {
   $self->pushCommand("save force");
 
   # 执行调度，配置批量下发
-  $self->execCommands( reverse $self->commands->@* );
+  $self->execCommands( $self->commands->@* );
 }
 
 __PACKAGE__->meta->make_immutable;
