@@ -9,6 +9,7 @@ use Try::Tiny;
 use Expect;
 use Moose::Role;
 use namespace::autoclean;
+use Mojo::Util qw/dumper/;
 
 #------------------------------------------------------------------------------
 # 继承 Netstack::Config::Connector::Role 必须实现的方法
@@ -302,7 +303,7 @@ sub send {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 waitfor，自动交互式执行脚本
+# 具体实现 waitfor，自动交互式执行脚本 | MORE 命令交互式输入 RT需要调整策略
 #------------------------------------------------------------------------------
 sub waitfor {
   my $self = shift;
@@ -318,7 +319,12 @@ sub waitfor {
   while ( my ( $wait, $action ) = each $mapping->%* ) {
     push $codeARef->@*, [
       $wait => sub {
+        # if ($wait =~ /more/i) {
+        #   $buff .= $exp->before;
+        # }
+        # else {
         $buff .= $exp->before . $exp->match;
+        # }
         $exp->send($action);
         exp_continue;
       }
@@ -332,6 +338,7 @@ sub waitfor {
   ];
 
   # 动态加载交互式代码
+  say dumper $codeARef;
   my @ret = $self->expect( 15, $codeARef->@* );
   # 异常捕捉
   if ( defined $ret[1] ) {
@@ -378,7 +385,7 @@ sub getConfig {
 #------------------------------------------------------------------------------
 sub execCommands {
   my ( $self, @commands ) = @_;
-
+  @commands = reverse @commands;
   # 判断是否已登陆设备
   if ( $self->status == 0 ) {
     $self->login;
@@ -408,7 +415,7 @@ sub execCommands {
   # 初始化 commands 属性
   $self->setCommands( \@commands );
   # 遍历接受到的命令行
-  while ( my $cmd = pop $self->commands->@* ) {
+  while ( my $cmd = pop @{$self->commands} ) {
     # 自动跳过空白行
     next if $cmd =~ /^\s*$/;
     # 执行具体的脚本
